<?php

namespace Drupal\clickandpledge_connect\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\RedirectResponse;
use \SoapClient;
use SimpleXMLElement;

/**
 * This Controller class handles all the AJAX calls for saving and updating the module data
 */
class CnPController extends ControllerBase
{
    
    /**
     * The constants 
     * 
     */
  const CFCNP_PLUGIN_UID = "14059359-D8E8-41C3-B628-E7E030537905";
  const CFCNP_PLUGIN_SKY = "5DC1B75A-7EFA-4C01-BDCD-E02C536313A3";
  const CFCNP_SOAP_VER = "SOAP_1_1";
  const CFCNP_SERVICE_URL = "https://resources.connect.clickandpledge.com/wordpress/Auth2.wsdl";
  
  /**
   *
   * @var type The Connection
   */
  private $connection=null;
  
  /**
   * The constructor
   */
  public function __construct() {
    $this->connection = \Drupal::service('database');
  }
  
  /**
   * 
   * @param type $variable1
   * @param type $variable2
   * @return JsonResponse The ajaxCallback
   * $variable1 holds AccountID and $variable2 holds GUID, by authenticating GUID and AccountID with service URL,
   * it will get the nickname for the account. Based on the nickname CONNECT forms will displayed.
   */
  public function ajaxCallback($variable1, $variable2)
  {
    $connect  = ['soap_version' => self::CFCNP_SOAP_VER, 'trace' => 1, 'exceptions' => 0];
    $client   = new SoapClient(self::CFCNP_SERVICE_URL, $connect);
    if (isset($variable1) && isset($variable2) && $variable1 != "" && $variable2 != "") {
      $accountid = $variable1;
      $accountguid = $variable2;
      $xmlr = new SimpleXMLElement("<GetAccountDetail></GetAccountDetail>");
      $xmlr->addChild('accountId', $accountid);
      $xmlr->addChild('accountGUID', $accountguid);
      $xmlr->addChild('username', self::CFCNP_PLUGIN_UID);
      $xmlr->addChild('password', self::CFCNP_PLUGIN_SKY);
      $response = $client->GetAccountDetail($xmlr);
      $responsearr =  $response->GetAccountDetailResult->AccountNickName;
      return new JsonResponse(["status" => $responsearr]);
    } else {
      return new JsonResponse(["status" => false]);
    }
  }
  
  /**
   * @param type $variable
   * @return JsonResponse
   * getAllCampaigns method will get all the campaigns based on nickname.
   * 
   */
  public function getAllCampaigns($variable)
  {
    $str = explode("@", $variable);
    $connect  = ['soap_version' => self::CFCNP_SOAP_VER, 'trace' => 1, 'exceptions' => 0];
    $client   = new SoapClient('https://resources.connect.clickandpledge.com/wordpress/Auth2.wsdl', $connect);
    $accountguid = $str[1];
    $accountid = $str[0];
    $xmlr  = new SimpleXMLElement("<GetActiveCampaignList2></GetActiveCampaignList2>");
    $xmlr->addChild('accountId', $accountid);
    $xmlr->addChild('AccountGUID', $accountguid);
    $xmlr->addChild('username', self::CFCNP_PLUGIN_UID);
    $xmlr->addChild('password', self::CFCNP_PLUGIN_SKY);
    $response = $client->GetActiveCampaignList2($xmlr);
    $responsearr =  $response->GetActiveCampaignList2Result->connectCampaign;
    $camrtrnval = "";
    $orderRes = [];
    if (count($responsearr) == 1) {
      $orderRes[$responsearr->alias] = $responsearr->name;
    } else {
      foreach ($responsearr as $obj) {
        $orderRes[$obj->alias] = $obj->name;
      }
    }
    natcasesort($orderRes);
    $camrtrnval .= "<option value=''>Select Campaign Name</option>";
    if (count($orderRes) > 0) {
      foreach ($orderRes as $key => $value) {
        $camrtrnval .= "<option value='" . $key . "'>" . $value . " (" . $key . ")</option>";
      }
    }
    return new JsonResponse(["data" => $camrtrnval]);
  }
  /**
   * @param type $variable
   * @return JsonResponse
   * getActivityForms method gets all the forms to user, to select the to be displayed.
   * This method depends on the response of getAllCampaigns method. Because each campaign holds groups of forms
   */
  public function getActivityForms($variable)
  {
    $str = explode("@", $variable);
    $connect  = ['soap_version' => self::CFCNP_SOAP_VER, 'trace' => 1, 'exceptions' => 0];
    $client   = new SoapClient('https://resources.connect.clickandpledge.com/wordpress/Auth2.wsdl', $connect);
    $cnpaccountID      = $str[0];
    $cnpaccountguidID  = $str[1];
    $cnpcampaignId     = $str[2];
    $xmlr  = new SimpleXMLElement("<GetActiveFormList2></GetActiveFormList2>");
    $xmlr->addChild('accountId', $cnpaccountID);
    $xmlr->addChild('AccountGUID', $cnpaccountguidID);
    $xmlr->addChild('username', self::CFCNP_PLUGIN_UID);
    $xmlr->addChild('password', self::CFCNP_PLUGIN_SKY);
    $xmlr->addChild('campaignAlias', $cnpcampaignId);
    $frmresponse    =  $client->GetActiveFormList2($xmlr);
    $frmresponsearr =  $frmresponse->GetActiveFormList2Result->form;
    $orderRes = [];
    if (count($frmresponsearr) == 1) {
      $orderRes[$frmresponsearr->formGUID] = $frmresponsearr->formName;
    } else {
      foreach ($frmresponsearr as $obj) {
        $orderRes[$obj->formGUID] = $obj->formName;
      }
    }
    natcasesort($orderRes);
    $rtrnval = "<option value=''>Select Form Name</option>";
    if (count($orderRes) > 0) {
      foreach ($orderRes as $key => $value) {
        $rtrnval .= "<option value='" . $key . "'>" . $value . "</option>";
      }
    }
    return new JsonResponse(["data" => $rtrnval]);
  }
  
  /**
   * The saveFormData 
   * Saves the connect forms data for both Add New Form Group and Edit Form Group
   * and also generates the short code only for form adding based on the details entered.
   * @return JsonResponse
   */
  public function saveFormData()
  {
    date_default_timezone_set(drupal_get_user_timezone());
    $data = filter_input_array(INPUT_POST, $_POST);
    $module_handler = \Drupal::service('module_handler');
    $module_path = $module_handler->getModule('clickandpledge_connect')->getPath();
    if (isset($_FILES) && !empty($_FILES)) {
      $filename = $_FILES['file']['name'];
      $tname = $_FILES['file']['tmp_name'];
      move_uploaded_file($tname, $module_path . "/banners/$filename");
    } else {
      if ($data['cnpc_action'] == "edit") {
        if(in_array("file",$data))
        {
          if ($data['file']) {
            $filename = $data['file'];
          } else {
            $filename = "";
          }
        }
        else
        {
          $filename="";
        }
      } else {
        $filename = "";
      }
    }
    $cnpc_account_str = explode("||", $data['cnpc_account']);
    $guid = $cnpc_account_str[1];
    $accid = $cnpc_account_str[0];
    $refId = $cnpc_account_str[2];
    $display_type = $data['cnpc_display_type'];
    $link_type = (isset($data['link_type'])) ? $data['link_type'] : "";
    $button_label = (isset($data['button_label'])) ? $data['button_label'] : "";
    if ($data['cnpc_end_datetime']) {
      $cnpc_end_datetime = date("Y-m-d h:i:s", strtotime($data['cnpc_end_datetime']));
    } else {
      $cnpc_end_datetime = "0000-00-00 00:00:00";
    }
    $cnpc_group_name = trim($data['cnpc_group_name']);
    $cnpc_group_name_shortcode = str_replace(' ', '-', $cnpc_group_name);
    $cnpc_message = $data['cnpc_message'];
    $cnpc_start_datetime = date("Y-m-d h:i:s", strtotime($data['cnpc_start_datetime']));
    $cnpc_status = $data['cnpc_status'];
    $shortcode = "[cnpform]" . $cnpc_group_name_shortcode . "[/cnpform]";
    $table_name1 = 'dp_cnpc_forminfo';
    $iID = [];
    if($data['cnpc_action'] === "add") {
      $query1 = $this->connection->insert($table_name1)
        ->fields([
          'cnpform_groupname',
          'cnpform_cnpstngs_ID',
          'cnpform_AccountNumber',
          'cnpform_guid',
          'cnpform_type',
          'cnpform_ptype',
          'cnpform_text',
          'cnpform_img',
          'cnpform_shortcode',
          'cnpform_custommsg',
          'cnpform_Form_StartDate',
          'cnpform_Form_EndDate',
          'cnpform_status',
          'cnpform_Date_Modified',
        ])
        ->values(array(
          $cnpc_group_name,
          $refId,
          $accid,
          $guid,
          $display_type,
          $link_type,
          $button_label,
          $filename,
          $shortcode,
          $cnpc_message,
          $cnpc_start_datetime,
          $cnpc_end_datetime,
          $cnpc_status,
          date("Y-m-d h:i:s"),
        ))
        ->execute();
    } else {
        $this->connection->update($table_name1)
        ->fields([
          'cnpform_groupname' => $cnpc_group_name,
          'cnpform_AccountNumber' => $accid,
          'cnpform_guid' => $guid,
          'cnpform_type' => $display_type,
          'cnpform_ptype' => $link_type,
          'cnpform_text' => $button_label,
          'cnpform_img' => $filename,
          'cnpform_shortcode' => $shortcode,
          'cnpform_custommsg' => $cnpc_message,
          'cnpform_Form_StartDate' => $cnpc_start_datetime,
          'cnpform_Form_EndDate' => $cnpc_end_datetime,
          'cnpform_status' => $cnpc_status,
          'cnpform_Date_Modified' => date("Y-m-d h:i:s"),
        ])
        ->condition('cnpform_GID', $data['cnpc_edit_id'])
        ->execute();
    }
    $table_name = 'dp_cnpc_formsdtl';
    if ($data['cnpc_action'] == "edit") {
      $nid = $data['cnpc_edit_id'];

      $did = $data['cnpc_edit_id'];
      $this->connection->delete($table_name)
        ->condition('cnpform_cnpform_ID', $did)
        ->execute();
    } else {
      $nid = $query1;
    }
    //Insert form group information
    $ls = explode("###", $data['cnpc_camp_list'], -1);
    $fs = explode("###", $data['cnpc_form_list'], -1);
    $gu = explode("###", $data['formguid'], -1);
    $sd = explode("###", $data['startdate'], -1);
    $ed = explode("###", $data['enddate'], -1);
    $pl = explode("###", $data['params_list'], -1);
    $form_list_titles = explode("###", $data['form_list_titles'], -1);
    for ($i = 0; $i < count($ls); $i++) {
      $cnamp_list = $ls[$i];
      $guid_list = $gu[$i];
      if ($pl[$i]) {
        $param_list = $pl[$i];
      } else {
        $param_list = "";
      }
      $sd_list = date("Y-m-d h:i:s", strtotime($sd[$i]));
      if ($ed[$i]) {
        $ed_list = date("Y-m-d h:i:s", strtotime($ed[$i]));
      } else {
        $ed_list = "0000-00-00 00:00:00";
      }
      $flt = $form_list_titles[$i];
      $query = $this->connection->insert($table_name)
        ->fields([
          'cnpform_cnpform_ID',
          'cnpform_CampaignName',
          'cnpform_FormName',
          'cnpform_GUID',
          'cnpform_FormStartDate',
          'cnpform_FormEndDate',
          'cnpform_FormStatus',
          'cnpform_urlparameters'
        ])
        ->values(array(
          $nid,
          $cnamp_list,
          $flt,
          $guid_list,
          $sd_list,
          $ed_list,
          $cnpc_status,
          $param_list,
        ))
        ->execute();
      $iID[] = $query;
    }
    if (count($iID) > 0) {
      return new JsonResponse(["data" => "success"]);
    } else {
      return new JsonResponse(["data" => "fail"]);
    }
  }
  
  /**
   * The updateFormStatus
   * $variableone holds form status(Active or Inactive) and $variabletwo holds id of the record to be updated
   * based on the status forms will be displayed to user for donations
   * @param type $variableone
   * @param type $variabletwo
   * @return JsonResponset
   */
  public function updateFormStatus($variableone, $variabletwo)
  {
    $table_name1 = 'dp_cnpc_forminfo';
    $num_updated = $this->connection->update($table_name1)
      ->fields([
        'cnpform_status' => $variableone,
      ])
      ->condition('cnpform_GID', $variabletwo)
      ->execute();
    if ($num_updated) {
      return new JsonResponse(["data" => "success"]);
    } else {
      return new JsonResponse(["data" => "fail"]);
    }
  }
  
  /**
   * The deleteFormDetails
   * Deletes the form details by clicking delete icon in settings tab. If any form groups are assigned to the form,
   * it wont be deleted.
   * @param type $variable
   * @return JsonResponse
   */
  public function deleteFormDetails($variable)
  {
    $table_name = 'dp_cnpc_formsdtl';
    $num_deleted = $this->connection->delete($table_name)
      ->condition('cnpform_id', $variable)
      ->execute();
    return new JsonResponse(array($num_deleted));
  }
  
  /**
   * deleteFormGroup
   * deletes the form groups
   * @param type $variable
   * @return JsonResponse
   */
  public function deleteFormGroup($variable)
  {
    $table_name = 'dp_cnpc_forminfo';
    $deleted_info = $this->connection->delete($table_name)
      ->condition('cnpform_GID', $variable)
      ->execute();
    if ($deleted_info) {
      $table_name1 = 'dp_cnpc_formsdtl';
        $this->connection->delete($table_name1)
        ->condition('cnpform_cnpform_ID', $variable)
        ->execute();
      $status = "success";
    } else {
      $status = "fail";
    }
    return new JsonResponse(["data" => $status]);
  }
  
  /**
   * cnpcRedirect
   * to redirect a page
   * @param type $path
   * @return type
   */
  function cnpcRedirect($path)
  {
    $response = new RedirectResponse($path, 302);
    $response->send();
    return;
  }
  /**
   * deleteSettingsDetails
   * deletes the setting details from settings tabs
   * @param type $variable
   * @return JsonResponse
   */
  public function deleteSettingsDetails($variable)
  {
    $prefix = $this->connection->tablePrefix();
    $table_name = $prefix . 'dp_cnpcsettingsdtl';
    $checkTable = $prefix . 'dp_cnpc_forminfo';
    $sql = "SELECT cnpform_groupname FROM " . $checkTable . " where cnpform_cnpstngs_ID=" . $variable;
    $query = $this->connection->query($sql);
    if (count($query->fetchAll()) == 0) {
      $deleted_dt1 = $this->connection->delete($table_name)
        ->condition('cnpstngs_ID', $variable)
        ->execute();
      if ($deleted_dt1) {
        return new JsonResponse(["data" => "success"]);
      } else {
        return new JsonResponse(["data" => "fail"]);
      }
    } else {
      return new JsonResponse(["data" => "fail"]);
    }
  }
  
  /**
   * refreshAccounts
   * it will get the updated data from CONNECT platform
   * @return JsonResponse
   */
  public function refreshAccounts()
  {
    $accid = filter_input(INPUT_POST, 'saccid');
    $guid = filter_input(INPUT_POST, 'sguid');
    $recid = filter_input(INPUT_POST, 'srecid');
    $connect  = ['soap_version' => self::CFCNP_SOAP_VER, 'trace' => 1, 'exceptions' => 0];
    $client   = new SoapClient(self::CFCNP_SERVICE_URL, $connect);
    if (isset($accid) && isset($guid) && $accid != "" && $guid != "") {
      $accountid = $accid;
      $accountguid = $guid;
      $xmlr = new SimpleXMLElement("<GetAccountDetail></GetAccountDetail>");
      $xmlr->addChild('accountId', $accountid);
      $xmlr->addChild('accountGUID', $accountguid);
      $xmlr->addChild('username', self::CFCNP_PLUGIN_UID);
      $xmlr->addChild('password', self::CFCNP_PLUGIN_SKY);
      $response = $client->GetAccountDetail($xmlr);
      $responsearr =  $response->GetAccountDetailResult->AccountNickName;
      $table_name = 'dp_cnpcsettingsdtl';
      $updated = $this->connection->update($table_name)
        ->fields([
          'cnpstngs_frndlyname' => $responsearr,
        ])
        ->condition('cnpstngs_ID', $recid)
        ->execute();
      if ($updated) {
        return new JsonResponse(["status" => "success"]);
      } else {
        return new JsonResponse(["status" => "fail"]);
      }
    } else {
      return new JsonResponse(["status" => "fail"]);
    }
  }
  
  /**
   * saveChannelData
   * saves the PledgeTV form data for both Add and Edit forms and generates the short code in adding form data only
   * @return JsonResponse
   */
  public function saveChannelData()
  {
    $data = $_POST;
    date_default_timezone_set(drupal_get_user_timezone());
    if ($data['cnpc_action'] != "edit") {
      $cnpc_account_str = explode("||", $data['cnpc_account']);
      $refId = $cnpc_account_str[2];
    }
    if ($data['cnpc_end_datetime']) {
      $cnpc_end_datetime = date("Y-m-d h:i:s", strtotime($data['cnpc_end_datetime']));
    } else {
      $cnpc_end_datetime = "0000-00-00 00:00:00";
    }
    $chnlcnpc_group_name = trim($data['cnpc_group_name']);
    $chnlcnpc_group_name_shortcode = str_replace(' ', '-', $chnlcnpc_group_name);
    $cnpc_message = $data['cnpc_message'];
    $cnpc_start_datetime = date("Y-m-d h:i:s", strtotime($data['cnpc_start_datetime']));
    $cnpc_status = $data['cnpc_status'];
    $shortcode = "[cnppledgetv]" . $chnlcnpc_group_name_shortcode . "[/cnppledgetv]";
    $table_name1 = 'dp_cnpc_channelgrp';
    $ciID = [];
    if ($data['cnpc_action'] == "add") {
      $query1 = $this->connection->insert($table_name1)
        ->fields([
          'cnpchannelgrp_groupname',
          'cnpchannelgrp_cnpstngs_ID',
          'cnpchannelgrp_shortcode',
          'cnpchannelgrp_custommsg',
          'cnpchannelgrp_channel_StartDate',
          'cnpchannelgrp_channel_EndDate',
          'cnpchannelgrp_status',
          'cnpchannelgrp_Date_Modified',
        ])
        ->values(array(
          $chnlcnpc_group_name,
          $refId,
          $shortcode,
          $cnpc_message,
          $cnpc_start_datetime,
          $cnpc_end_datetime,
          $cnpc_status,
          date("Y-m-d h:i:s"),
        ))
        ->execute();
    } else {
      $cnpc_account_str = explode("||", $data['cnpc_account']);
      $refId = $cnpc_account_str[2];
      $table_name1 = 'dp_cnpc_channelgrp';
      $this->connection->update($table_name1)
        ->fields([
          'cnpchannelgrp_groupname' => $chnlcnpc_group_name,
          'cnpchannelgrp_cnpstngs_ID' => $refId,
          'cnpchannelgrp_shortcode' => $shortcode,
          'cnpchannelgrp_custommsg' => $cnpc_message,
          'cnpchannelgrp_channel_StartDate' => $cnpc_start_datetime,
          'cnpchannelgrp_channel_EndDate' => $cnpc_end_datetime,
          'cnpchannelgrp_status' => $cnpc_status,
          'cnpchannelgrp_Date_Modified' => date("Y-m-d h:i:s"),
        ])
        ->condition('cnpchannelgrp_ID', $data['cnpc_edit_id'])
        ->execute();
    }
    $table_name = 'dp_cnpc_channeldtl';
    if ($data['cnpc_action'] == "edit") {
      $nid = $data['cnpc_edit_id'];

      $did = $data['cnpc_edit_id'];
      $this->connection->delete($table_name)
        ->condition('cnpchannel_cnpchannelgrp_ID', $did)
        ->execute();
    } else {
      $nid = $query1;
    }
    //Insert Channel group information
    $ls = explode("###", $data['cnpc_chnl_list'], -1);
    $sd = explode("###", $data['chnlstartdate'], -1);
    $ed = explode("###", $data['chnlenddate'], -1);
    for ($i = 0; $i < count($ls); $i++) {
      $cnamp_list = $ls[$i];
      $sd_list = date("Y-m-d h:i:s", strtotime($sd[$i]));
      if ($ed[$i]) {
        $ed_list = date("Y-m-d h:i:s", strtotime($ed[$i]));
      } else {
        $ed_list = "0000-00-00 00:00:00";
      }
      $cquery = $this->connection->insert($table_name)
        ->fields([
          'cnpchannel_cnpchannelgrp_ID',
          'cnpchannel_channelName',
          'cnpchannel_channelStartDate',
          'cnpchannel_channelEndDate',
          'cnpchannel_channelStatus',
        ])
        ->values(array(
          $nid,
          $cnamp_list,
          $sd_list,
          $ed_list,
          $cnpc_status,
        ))
        ->execute();
      $ciID[] = $cquery;
    }
    if (count($ciID) > 0) {
      return new JsonResponse(["data" => "success"]);
    } else {
      return new JsonResponse(["data" => "fail"]);
    }
  }
  
  /**
   * deletechannelDetails
   * delete channel information from pledgeTV
   * @param type $variable
   * @return JsonResponse
   */
  public function deletechannelDetails($variable)
  {
    $table_name = 'dp_cnpc_channeldtl';
    $num_deleted = $this->connection->delete($table_name)
      ->condition('cnpchannel_id', $variable)
      ->execute();
    return new JsonResponse(array($num_deleted));
  }
  
  /**
   * deletechannelGroup
   * delete channel forms
   * @param type $variable
   * @return JsonResponse
   */
  public function deletechannelGroup($variable)
  {
    $table_name = 'dp_cnpc_channelgrp';
    $deleted_info = $this->connection->delete($table_name)
      ->condition('cnpchannelgrp_ID', $variable)
      ->execute();
    if ($deleted_info) {
      $table_name1 = 'dp_cnpc_channeldtl';
      $this->connection->delete($table_name1)
        ->condition('cnpchannel_cnpchannelgrp_ID', $variable)
        ->execute();
      $status = "success";
    } else {
      $status = "fail";
    }
    return new JsonResponse(["data" => $status]);
  }
  
  /**
   * getAllChannels
   * get the channel information based on GUID and AccountID, $variable contains the information about GUID and AccountID
   * @param type $variable
   * @return JsonResponse
   */
  public function getAllChannels($variable)
  {
    $str = explode("@", $variable);
    $connect  = ['soap_version' => self::CFCNP_SOAP_VER, 'trace' => 1, 'exceptions' => 0];
    $module_handler = \Drupal::service('module_handler');
    $module_path = $module_handler->getModule('clickandpledge_connect')->getPath() . "/Auth2.wsdl";
    $client   = new SoapClient($module_path, $connect);
    $camrtrnval = "";
    $caccountguid = $str[1];
    $caccountid = $str[0];
    $xmlr  = new SimpleXMLElement("<GetPledgeTVChannelList></GetPledgeTVChannelList>");
    $xmlr->addChild('accountId', $caccountid);
    $xmlr->addChild('AccountGUID', $caccountguid);
    $xmlr->addChild('username', self::CFCNP_PLUGIN_UID);
    $xmlr->addChild('password', self::CFCNP_PLUGIN_SKY);
    $response = $client->GetPledgeTVChannelList($xmlr);
    $responsearr =  $response->GetPledgeTVChannelListResult->PledgeTVChannel;
    $orderRes = [];
    if (count($responsearr) == 1) {
      $orderRes[$responsearr->ChannelURLID] = $responsearr->ChannelName;
    } else {
      foreach ($responsearr as $obj) {
        $orderRes[$obj->ChannelURLID] = $obj->ChannelName;
      }
    }
    natcasesort($orderRes);
    $camrtrnval .= "<option value=''>Select channels</option>";
    if (count($orderRes) > 0) {
      foreach ($orderRes as $key => $value) {
        $camrtrnval .= "<option value='" . $key . "'>" . $value . " (" . $key . ")</option>";
      }
    }
    return new JsonResponse(["data" => $camrtrnval]);
  }
  
  /**
   * updatePTVFormStatus
   * To update the form status(Active or Inactive)
   * @param type $variable1
   * @param type $variable2
   * @return JsonResponse
   */
  public function updatePTVFormStatus($variable1, $variable2)
  {
    $table_name1 = 'dp_cnpc_channelgrp';
    $num_updated = $this->connection->update($table_name1)
      ->fields([
        'cnpchannelgrp_status' => $variable1,
      ])
      ->condition('cnpchannelgrp_ID', $variable2)
      ->execute();
    if ($num_updated) {
      return new JsonResponse(["data" => "success"]);
    } else {
      return new JsonResponse(["data" => "fail"]);
    }
  }
  
  /**
   * deleteTVFormDetails
   * delete the forms details based on form id
   * @param type $variable
   * @return JsonResponse
   */
  public function deleteTVFormDetails($variable)
  {
    $table_name = 'dp_cnpc_channeldtl';
    $num_deleted = $this->connection->delete($table_name)
      ->condition('cnpchannel_id', $variable)
      ->execute();
    return new JsonResponse(array($num_deleted));
  }
  
  /**
   * accountVerification
   * verifies the account based on account number
   * @param type $variable
   * @return JsonResponse
   */
  public function accountVerification($variable)
  {
    $prefix = $this->connection->tablePrefix();
    $table_name = $prefix . 'dp_cnpcsettingsdtl';
    $sql = "SELECT cnpstngs_frndlyname,cnpstngs_AccountNumber FROM " . $table_name . " where cnpstngs_AccountNumber='$variable'";
    $query = $this->connection->query($sql);
    return new JsonResponse(count($query->fetchAll()));
  }
  
  /**
   * formGroupVerification
   * verifies the form group based on form group name
   * @param type $variable1
   * @return JsonResponse
   */
  public function formGroupVerification($variable1)
  {
    $prefix = $this->connection->tablePrefix();
    $table_name = $prefix . 'dp_cnpc_forminfo';
    $sql = "SELECT cnpform_groupname FROM " . $table_name . " where cnpform_groupname='$variable1'";
    $query = $this->connection->query($sql);
    return new JsonResponse(count($query->fetchAll()));
  }
  
  /**
   * channelGroupVerification
   * verifies the channel information based on channel group name
   * @param type $variable
   * @return JsonResponse
   */
  public function channelGroupVerification($variable)
  {
    $prefix = $this->connection->tablePrefix();
    $table_name = $prefix . 'dp_cnpc_channelgrp';
    $sql = "SELECT cnpchannelgrp_groupname FROM " . $table_name . " where cnpchannelgrp_groupname='$variable'";
    $query = $this->connection->query($sql);
    return new JsonResponse(count($query->fetchAll()));
  }
  
}
