<?php

namespace Drupal\clickandpledge_connect\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * AddFormGroup
 * uses to create CONNECT forms
 */
class AddFormGroup extends FormBase
{
  /**
    * {@inheritdoc}
  */
  public function getFormId()
  {
    return "cnpcaccount_add_form_group";
  }
  
  /**
    * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state)
  {
    $displayForm = $this->displayAccountSettingsForm($form, $form_state);
    return $displayForm;
  }
  
  /**
   * displayAccountSettingsForm
   * creates a CONNECT form
   * @param type $form
   * @param type $form_state
   * @return string
   */
  public function displayAccountSettingsForm($form, $form_state)
  {
    date_default_timezone_set(drupal_get_user_timezone());
    $form['cnpc_menu'] = [
      '#prefix' => '<div class="cnp_heading"><ul>'
        . '<li><a href="cnp_form_help">'.$this->t("Click & Pledge").'</a></li>'
        . '<li><a class="cnpccurrent" href="cnp_form">'.$this->t("Form Groups").'</a></li>'
        . '<li><a href="cnppledgetvchannels">'.$this->t("pledgeTV").'<sup class="cnpc-regsymbol">&reg;</sup></a></li>'
        . '<li><a href="cnp_formssettings">'.$this->t("Settings").'</a></li>'
        . '</ul>',
      '#suffix' => '</div>',
    ];
    $form['cnpc_heading'] = [
      '#prefix' => '<div class="cnp_heading1">',
      '#suffix' => '</div>',
    ];
    $form['cnpc_form_group_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Form Group Name*'),
      '#description' => $this->t('Please enter the form group name<br><span class="cnpc_formexists_error"></span>'),
      '#default_value' => '',
      '#attributes' => ["id" => "cnpc_form_group_name"],
    ];
    $data = $this->getRecords();
    if (count($data) > 0) {
      if (count($data) == 1) {
        $disabled = TRUE;
      } else {
        $disabled = FALSE;
      }
    } else {
      $disabled = false;
    }
    $options = [];
    foreach ($data as $rec) {
      $options[trim($rec->cnpstngs_AccountNumber) . "||" . trim($rec->cnpstngs_guid) . "||" . trim($rec->cnpstngs_ID)] = $rec->cnpstngs_frndlyname . ' ( ' . $rec->cnpstngs_AccountNumber . ' ) ';
    }
    $form['base_url_cnpc'] = [
      '#type' => 'hidden',
      '#default_value' => base_path(),
      '#attributes' => ["id" => "base_url_cnpc"],
    ];
    $form['cnpc_action'] = [
      '#type' => 'hidden',
      '#default_value' => 'add',
      '#attributes' => ["id" => "cnpc_action"],
    ];
    /*URL Params popup Starts*/
    $form['cnpc_params_popup'] = [
      "#prefix" => '<div id="cnpc_myModal" class="cnpc-modal">
                <div class="cnpc-modal-content">
                  <div class="cnpc-modal-header">
                    <span class="cnpc-close">&times;</span>
                    <h2>'.$this->t("URL Parameter(s)").'</h2>
                  </div>
                  <div class="cnpc-modal-body">'
    ];
    $form['cnpc_params_textarea'] = [
      "#prefix" => '<div class="cnpc-form-group-params">',
      "#type" => "textarea",
      "#atrributes" => ['class' => ['paramsfeild']],
      "#suffix" => "</div>",
    ];
    $form['cnpc_params_textarea']['#theme_wrappers'] = [];
    $form["cnpc_params_buttons_start"] = [
      "#prefix" => "</div><div class='cnpc-modal-footer'>",
    ];
    $form['cnpc_params_button_add'] = [
      "#prefix" => '<div>',
      '#type' => 'button',
      '#value' => $this->t('Add'),
      '#attributes' => ['class' => ['popupsavebtn'], "id" => "addparams"],
      "#suffix" => '</div>',
    ];
    $form['cnpc_params_button_close'] = [
      "#prefix" => '<div>',
      '#type' => 'button',
      '#value' => $this->t('Close'),
      '#attributes' => ['class' => ['popupclosebtn'], "id" => "closeparams"],
      "#suffix" => '</div>',
    ];
    $form['cnpc_params_button_saveclose'] = [
      "#prefix" => '<div>',
      '#type' => 'button',
      '#value' => $this->t('Add & Close'),
      '#attributes' => ['class' => ['popupsaveclosebtn'], "id" => "savecloseparams"],
      "#suffix" => '</div>',
    ];
    $html22 = '</div><p class="cnpc_note_text"><b>'.$this->t("Note:").'</b> '.$this->t("Separate with ampersand (&)").' <a target="_blank" href="https://support.clickandpledge.com/s/article/connect-url-parameters1"><b>'.$this->t("Read More...").'</b></a></p>';
    $form['readmore_link_html22'] = [
      '#type' => 'markup',
      '#markup' => $html22,
    ];
    $form["cnpc_params_buttons_end"] = [
      "#suffix" => "</div></div>",
    ];
    /** URL Params popup Ended **/
    $form['cnpc_accounts'] = [
      '#type' => 'select',
      '#title' => $this->t('Account(s)*'),
      '#options' => $options,
      '#attributes' => ["id" => "cnpc_accounts"],
      '#disabled' => $disabled,
    ];
    $form['cnpc_start_date_time'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Start Date/Time* [TimeZone: ' . drupal_get_user_timezone() . ']'),
      '#attributes' => ["id" => "start_date_time"],
      '#default_value' => date("F d, Y h:i a"),
    ];
    $form['cnpc_end_date_time'] = [
      '#type' => 'textfield',
      '#title' => $this->t('End Date/Time'),
      '#attributes' => ["id" => "end_date_time"],
      '#default_value' => '',
    ];
    $form['cnpc_display_type'] = [
      '#type' => 'select',
      '#title' => $this->t('Display Type'),
      '#options' => ["inline" => "Inline", "popup" => "Overlay"],
      '#attributes' => ["id" => "cnpc_display_type"],
    ];
    //hidden form overlay
    $form['overlay_wrapper_start'] = [
      '#prefix' => '<div class="overlay_wrapper">',
    ];
    $form['cnpc_link_type'] = [
      '#type' => 'select',
      '#title' => $this->t('Link Type*'),
      '#options' => ["button" => $this->t("Button"), "image" => $this->t("Image"), "text" => $this->t("Text")],
      '#attributes' => ["id" => "cnpc_link_type"],
    ];
    $form['cnpc_buton_label'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Button Label*'),
      '#attributes' => ["id" => "cnpc_btn_lbl"],
      '#default_value' => '',
    ];
    $form['cnpc_upload_image'] = [
      '#type' => 'file',
      '#title' => $this->t('Upload Image*'),
      '#attributes' => ["id" => "cnpc_upload_image"],
      '#default_value' => '',
    ];
    $form['overlay_wrapper_end'] = [
      '#suffix' => '</div>',
    ];

    $form['cnpc_message'] = [
      '#type' => 'textarea',
      '#title' => $this->t('No Valid Form Message'),
      '#attributes' => ["id" => "cnpc_message"],
      '#default_value' => $this->t('No donations are accepted at this time'),
    ];
    $form['cnpc_status'] = [
      '#type' => 'select',
      '#title' => $this->t('Status'),
      '#options' => ["active" => "Active", "inactive" => "Inactive"],
      '#attributes' => ["id" => "cnpc_status"],
    ];
    $form['cnpc_counter'] = [
      '#type' => 'hidden',
      '#attributes' => ["id" => "cnpc_counter"],
      '#default_value' => 0,
    ];
    //hidden form Starts here
    $form['cnpc_settings_form_start'] = [
      '#prefix' => '<div class="cnpc_settings_form" id="cnpc_settings_form">'.$this->t('Select your CONNECT campaign, choose a payment form, enter a start date and click SAVE. Copy the shortcode from Click & Pledge Form Groups page to enter on your WordPress page. Multiple forms may be added to display in order by start date. If dates overlap, the first form in the list will show.').''
        . '<table id="custrows"><tr>
        <th>'.$this->t("Campaign*").'</th>
        <th>'.$this->t("Form*").'</th>
        <th>'.$this->t("Form GUID*").'</th>
        <th>'.$this->t("Start Date/Time*").'</th>
        <th>'.$this->t("End Date/Time").'</th>
        <th>&nbsp;</th>
        </tr><tbody id="dynarows"></tbody></table><a href="#" id="addrows">'.$this->t('Add Form').'</a>',
    ];
    $form['cnpc_settings_form_end'] = [
      '#suffix' => '</div>'
    ];
    $form['cnpc_inital_buttons_start'] = [
      '#prefix' => '<div class="cnpc_inital_buttons">',
    ];
    $form['save'] = [
      '#type' => 'button',
      '#value' => $this->t('Save'),
      '#attributes' => ["id" => "savebtn"],
    ];
    $html2 = '<a id="resetbtn" href="cnp_form" class="button button--reset js-form-submit form-submit">'.$this->t("Close").'</a>';
    $form['gobackbtn_link_html2'] = [
      '#type' => 'markup',
      '#markup' => $html2,
    ];
    $form['cnpc_inital_buttons_end'] = [
      '#suffix' => '</div>',
    ];
    $form['cnpc_hide_buttons_start'] = [
      '#prefix' => '<div class="cnpc_hide_show_buttons">',
    ];
    $form['final_save'] = [
      '#type' => 'button',
      '#value' => $this->t('Save'),
      '#attributes' => ["id" => "finalsave"],
    ];
    $html3 = '<a href="cnp_form" class="button button--reset js-form-submit form-submit">'.$this->t("Close").'</a>';
    $form['gobackbtn_link_html3'] = [
      '#type' => 'markup',
      '#markup' => $html3,
    ];
    $form['cnpc_hide_buttons_end'] = [
      '#suffix' => '</div>'
    ];
    return $form;
  }
  
  /**
    * {@inheritdoc}
  */
  public function validateForm(array &$form, FormStateInterface $form_state)
  {
    //form validations are handling with javascript
  }
  
  /**
    * {@inheritdoc}
  */
  public function submitForm(array &$form, FormStateInterface $form_state)
  {
    //form data is saving with ajax calls
  }
  
  /**
   * getRecords
   * get all the accounts and displayed on accounts drop down in the form
   * @return type
   */
  public function getRecords()
  {
    $connection = \Drupal::database();
    $prefix = $connection->tablePrefix();
    $table_name = $prefix . 'dp_cnpcsettingsdtl';
    $sql = "SELECT cnpstngs_ID,cnpstngs_frndlyname,cnpstngs_AccountNumber,cnpstngs_guid,cnpstngs_status,cnpstngs_Date_Created,cnpstngs_Date_Modified FROM " . $table_name;
    $query = $connection->query($sql);
    return $query->fetchAll();
  }
  
}
