<?php

namespace Drupal\clickandpledge_connect\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\FormBase;

/**
 * uses to display all CONNECT forms, where we can display icons to perform VIEW,EDIT,DELETE operations
 */
class CnPAccountForm extends FormBase
{
  /**
   *Database connection
   * @var type 
   */
  private $connection=null;
  
  /**
   * Constructor
   * loads database
   */
  public function __construct() {
    $this->connection = \Drupal::service('database');
  }
  /**
    * {@inheritdoc}
   **/
  public function getFormId()
  {
    return "cnpcaccount_settings_form";
  }
  
  /**
    * {@inheritdoc}
   **/
  public function buildForm(array $form, FormStateInterface $form_state)
  {
    $displayForm = $this->displayAccountSettingsForm($form, $form_state);
    return $displayForm;
  }
  
  /**
   * displayAccountSettingsForm
   * Display all connect forms from the database
   * @param type $form
   * @param type $form_state
   * @return string
   */
  public function displayAccountSettingsForm($form, $form_state)
  {
    $form['base_url_cnpc'] = [
      '#type' => 'hidden',
      '#default_value' => base_path(),
      '#attributes' => ["id" => "base_url_cnpc"],
    ];
    $form['cnpc_menu'] = [
      '#prefix' => '<div class="cnp_heading"><ul>'
        . '<li><a href="cnp_form_help">'.$this->t("Click & Pledge").'</a></li>'
        . '<li><a class="cnpccurrent" href="cnp_form">'.$this->t("Form Groups").'</a></li>'
        . '<li><a href="cnppledgetvchannels">'.$this->t("pledgeTV").'<sup class="cnpc-regsymbol">&reg;</sup></a></li>'
        . '<li><a href="cnp_formssettings">'.$this->t("Settings").'</a></li>'
        . '</ul>',
      '#suffix' => '</div>',
    ];
    $form['cnpc_heading'] = [
      '#prefix' => '<div class="cnp_heading1">',
      '#suffix' => '</div>',
    ];
    $html = '<div class="cnpc-btn-center"><a href="add_form_group" class="cnpc_button_link_add">'.$this->t("Add New Form Group").'</a></div>';
    $form['button_link_html'] = [
      '#type' => 'markup',
      '#markup' => $html,
    ];
    $form['table_group_start'] = [
      "#prefix" => "<div class='tablelist_group'>",
    ];
    if (count($this->getRecords()) > 0) {
      $form['table_tag_start'] = [
        "#prefix" => "<div><table id='table_form_group' class='table_form_group'>
                            <thead>
                                <tr>
                                    <th>".$this->t("Group Name")."</th>
                                    <th>".$this->t("Account#")."</th>
                                    <th>".$this->t("Type")."</th>
                                    <th>".$this->t("Short Code")."<span class='cnpc_question'>&#63;</span><div class='cnpc_shortcode_tooltip'>".$this->t("Please copy this code and place it in your required content pages, posts or any custom content types. This code will run the series of the forms which has been added to this particular Form Group inside your content page.")."</div></th>
                                    <th>".$this->t("Start Date/Time")."</th>
                                    <th>".$this->t("End Date/Time")."</th>
                                    <th>".$this->t("Active Form(s)")."</th>
                                    <th>".$this->t("Last Modified")."</th>
                                    <th>".$this->t("Status")."</th>
                                    <th>".$this->t("Actions")."</th>
                                </tr>
                            </thead>
                            <tbody>"
      ];
      $formGroups = $this->getRecords();
      $rg = 1;
      foreach ($formGroups as $fg) {
        if ($fg->cnpform_Form_EndDate == "0000-00-00 00:00:00") {
          $enddate = "";
        } else {
          $enddate = date("F d, Y h:i:s a", strtotime($fg->cnpform_Form_EndDate));
        }

        if ($this->checkFormsExpiry($fg->cnpform_Form_StartDate, $enddate) == "no") {
          $flink = "<a id='formstatus_" . $fg->cnpform_GID . "' class='formstatus' href='' data-fgid='" . $fg->cnpform_GID . "' data-fstatus='" . $fg->cnpform_status . "'>" . $fg->cnpform_status . "</a>";
        } else {
          $flink = "<a class='formstatus'>Expired</a>";
        }
        $form['table_row_form_groups_' . $rg] = [
          "#prefix" => "<tr>
                                   <td>" . $fg->cnpform_groupname . "</td>
                                   <td>" . $fg->cnpform_AccountNumber . "</td>
                                   <td><span class='cnpform_type'>" . $fg->cnpform_type . "</span></td>
                                   <td>" . $fg->cnpform_shortcode . "</td>
                                   <td>" . date("F d, Y h:i:s a", strtotime($fg->cnpform_Form_StartDate)) . "</td>
                                   <td>" . $enddate . "</td>
                                   <td>" . count($this->getNoofForms($fg->cnpform_GID)) . "</td>
                                   <td>" . date("F d, Y h:i:s a", strtotime($fg->cnpform_Date_Modified)) . "</td>
                                   <td>" . $flink . "</td>
                                   <td><a href='viewforms/" . $fg->cnpform_GID . "'><span class='view_icon'></span></a> | <a href='editforms/" . $fg->cnpform_GID . "'><span class='edit_icon'></span></a> | <a id='deleteFormInfo' class='deleteFormInfo' data-recid='" . $fg->cnpform_GID . "' href='#'><span class='bin_icon'></span></a> </td>",
          "#suffix" => "</tr>",
        ];
        $rg++;
      }
      $form['table_tag_end'] = [
        "#suffix" => "</tbody></table></div>",
      ];
    } else {
      $form['no_records'] = [
        "#prefix" => "<div><h3>".$this->t("No Records Found.")."</h3>",
        "#suffix" => "</div>",
      ];
    }
    $form['table_group_end'] = [
      "#suffix" => "</div>",
    ];
    return $form;
  }
  
  /**
    * {@inheritdoc}
   **/
  public function validateForm(array &$form, FormStateInterface $form_state)
  {
    //form validations are hasling with javascript
  }
  
  /**
    * {@inheritdoc}
   **/
  public function submitForm(array &$form, FormStateInterface $form_state)
  {
    //saving form data handling with ajax call
  }
  
  /**
   * getRecords
   * get all the CONNECT form records 
   * @return type
   */
  public function getRecords()
  {
    $prefix = $this->connection->tablePrefix();
    $table_name = $prefix . 'dp_cnpc_forminfo';
    $sql = "SELECT cnpform_GID,cnpform_groupname,cnpform_cnpstngs_ID,cnpform_AccountNumber,"
            . "cnpform_guid,cnpform_type,cnpform_ptype,cnpform_text,cnpform_img,cnpform_shortcode,"
            . "cnpform_custommsg,cnpform_Form_StartDate,cnpform_Form_EndDate,cnpform_status,"
            . "cnpform_Date_Created,cnpform_Date_Modified FROM " . $table_name;
    $query = $this->connection->query($sql);
    return $query->fetchAll();
  }
  
  /**
   * getNoofForms
   * get total no.of forms to display the count in the table view
   * @param type $id
   * @return type
   */
  public function getNoofForms($id)
  {
    $prefix = $this->connection->tablePrefix();
    $table_name = $prefix . 'dp_cnpc_formsdtl';
    $sql = "SELECT cnpform_id,cnpform_cnpform_ID,cnpform_CampaignName,cnpform_FormName,cnpform_GUID,"
            . "cnpform_FormStartDate,cnpform_FormEndDate,cnpform_urlparameters,cnpform_FormStatus,"
            . "cnpform_DateCreated,cnpform_DateModified FROM " . $table_name . " where cnpform_cnpform_ID=" . $id;
    $query = $this->connection->query($sql);
    return $query->fetchAll();
  }
  
  /**
   * checkFormsExpiry
   * calculates the expiration date of CONNECT form,if expired,displays 'Expired'
   * @param type $startDT
   * @param type $endDT
   * @return string
   */
  public function checkFormsExpiry($startDT, $endDT)
  {
    date_default_timezone_set(drupal_get_user_timezone());
    $currDT = date('Y-m-d h:i:s a');
    $currDT = strtotime($currDT);
    $startDT = strtotime($startDT);
    $endDT = strtotime($endDT);
    if($startDT > $currDT)
    {
        return "no";
    }
    if ($endDT) {
      if (($currDT >= $startDT) && ($currDT <= $endDT)) {
        return "no";
      } else {
        return "yes";
      }
    } else {
      return "no";
    }
  }
  
}
