<?php

namespace Drupal\clickandpledge_connect\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 *  Uses to create a form, that verifies AccoundID and GUID with CONNECT platform
 * after verification, it stores the data with nickname in table
 */
class CnPAccountSettings extends FormBase
{
   /**
    *Database connection
    * @var type 
    */
  private $connection=null;
  
  /**
   * Construct
   * loads database  connection
   */
  public function __construct() {
    $this->connection = \Drupal::service('database');
  }
  
  /**
    * {@inheritdoc}
   */
  public function getFormId()
  {
    return "cnpc_account_settings_form";
  }
  
  /**
    * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state)
  {
    $displayForm = $this->displayAccountSettingsForm($form,  $form_state);
    return $displayForm;
  }
  
  /**
   * displayAccountSettingsForm
   * Create a form to verify account details GUID and AccountID
   * @param type $form
   * @param type $form_state
   * @return string
   */
  public function displayAccountSettingsForm($form, $form_state)
  {
    if (count($this->getRecords()) > 0) {
      $form['cnpc_menu'] = [
        '#prefix' => '<div class="cnp_heading"><ul>'
          . '<li><a href="cnp_form_help">'.$this->t("Click & Pledge").'</a></li>'
          . '<li><a href="cnp_form">'.$this->t("Form Groups").'</a></li>'
          . '<li><a href="cnppledgetvchannels">'.$this->t("pledgeTV").'<sup class="cnpc-regsymbol">&reg;</sup></a></li>'
          . '<li><a class="cnpccurrent" href="cnp_formssettings">'.$this->t("Settings").'</a></li>'
          . '</ul>',
        '#suffix' => '</div>',
      ];
    }
    $form['cnpc_error_msg'] = [
      '#prefix' => '<div class="cnpc_error_msg" id="alertmsg">'.$this->t("Hi User!"),
      '#suffix' => '</div>',
    ];
    $form['cnpc_account_number'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Click & Pledge Account Number*'),
      '#description' => $this->t('Please enter the Account Number of your CONNECT Account<br>[CONNECT > Launcher > Settings > API Information > Account ID]<br><span class="cnpc_exists_error"></span>'),
      '#default_value' => '',
      '#attributes' => ["id" => "cnpc_account_number"],
    ];
    $form['cnpc_account_guid'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Click & Pledge Account GUID*'),
      '#description' => $this->t('Please enter the Account <a href="https://support.clickandpledge.com/s/article/how-to-locate-account-id--api-account-guid" target="_blank">GUID</a> of your CONNECT Account<br>[CONNECT > Launcher > Settings > API Information > API (PaaS / FaaS): Account GUID].'),
      '#default_value' => '',
      '#attributes' => ["id" => "cnpc_account_guid"],
    ];
    $form['base_url_cnpc'] = [
      '#type' => 'hidden',
      '#default_value' => base_path(),
      '#attributes' => ["id" => "base_url_cnpc"],
    ];
    $form['nickname_cnpc'] = [
      '#type' => 'hidden',
      '#default_value' => "",
      '#attributes' => ["id" => "nickname_cnpc"],
    ];
    $form['response_cnpc'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Nickname*'),
      '#default_value' => "",
      '#attributes' => ["id" => "response_cnpc", "disabled" => "disabled"],
      "#prefix" => "<div class='nickname-div'>",
      "#suffix" => "</div>",
    ];
    $form['save'] = [
      '#type' => 'submit',
      '#input' => TRUE,
      '#value' => $this->t('Verify'),
    ];
    $form['page_break'] = [
      '#prefix' => '<div class="page_break">',
      '#suffix' => '</div>',
    ];
    if (count($this->getRecords()) > 0) {
      $form['table_start'] = [
        "#prefix" => "<div class='tablelist'>",
      ];
      $form['table_tag_start'] = [
        "#prefix" => "<div><table id='table_id' class='display'>
                            <thead>
                                <tr>
                                    <th>".$this->t("Nickname")."</th>
                                    <th>".$this->t("Account Number")."</th>
                                    <th>".$this->t("GUID")."</th>
                                    <th>".$this->t("Created Date/Time")."</th>
                                    <th>".$this->t("Actions")."</th>
                                </tr>
                            </thead>
                            <tbody>"
      ];
      $datarec = $this->getRecords();
      $k = 1;
      foreach ($datarec as $rec) {
        $form['table_row' . $k] = [
          "#prefix" => "<tr>
                        <td>" . $rec->cnpstngs_frndlyname . "</td>
                        <td>" . $rec->cnpstngs_AccountNumber . "</td>
                        <td>" . $rec->cnpstngs_guid . "</td>
                        <td>" . date("F d, Y h:i a", strtotime($rec->cnpstngs_Date_Created)) . "</td>
                        <td><a href='#' data-settid='" . $rec->cnpstngs_ID . "' data-settaccid='" . $rec->cnpstngs_AccountNumber . "' data-settguid=" . $rec->cnpstngs_guid . " class='refreshAccounts' id='refreshacc_" . $rec->cnpstngs_ID . "' ><span class='refresh_icon'></span></a> &nbsp;|&nbsp; <a href='#' class='settingsDel' id='settingsDel' data-settrecid='" . $rec->cnpstngs_ID . "'><span class='bin_icon'></span></a></td>",
          "#suffix" => "</tr>",
        ];
        $k++;
      }
      $form['table_tag_end'] = [
        "#suffix" => "</tbody>
                            </table></div>",
      ];
      $form['table_end'] = [
        "#suffix" => "</div>",
      ];
    }
    return $form;
  }
  
  public function validateForm(array &$form, FormStateInterface $form_state)
  {
    //form validations are handling with javascript
  }
  
  /**
    * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state)
  {
    $accNumber = ($form_state->getValue('cnpc_account_number')) ? $form_state->getValue('cnpc_account_number') : "";
    $accGuid = ($form_state->getValue('cnpc_account_guid')) ? $form_state->getValue('cnpc_account_guid') : "";
    $nickname = ($form_state->getValue('nickname_cnpc')) ? $form_state->getValue('nickname_cnpc') : "";
    $nickname = trim($nickname);
    $accNumber = trim($accNumber);
    $accGuid = trim($accGuid);
    $table_name = 'dp_cnpcsettingsdtl';
    $this->connection->insert($table_name)
      ->fields([
        'cnpstngs_frndlyname',
        'cnpstngs_AccountNumber',
        'cnpstngs_guid',
      ])
      ->values(array(
        $nickname,
        $accNumber,
        $accGuid,
      ))
      ->execute();
  }
  
  /**
   * getRecords
   * get all the account details
   * @return type
   */
  public function getRecords()
  {
    $connection = \Drupal::database();
    $prefix = $this->connection->tablePrefix();
    $table_name = $prefix . 'dp_cnpcsettingsdtl';
    $sql = "SELECT cnpstngs_ID,cnpstngs_frndlyname,cnpstngs_AccountNumber,cnpstngs_guid,cnpstngs_status,"
            . "cnpstngs_Date_Created,cnpstngs_Date_Modified FROM " . $table_name;
    $query = $this->connection->query($sql);
    return $query->fetchAll();
  }
  
}
