<?php

namespace Drupal\clickandpledge_connect\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\FormBase;

/**
 * Uses to display pledgeTV channels in a table
 */
class CnPpledgeTVChannels extends FormBase
{
  
  /**
   * Database connection
   * @var type 
   */
  private $connection=null;
  
  /**
   * Constructor to load database connection into class
   */
  public function __construct() {
    $this->connection = \Drupal::service('database');
  }
  
  /**
    * {@inheritdoc}
   */
  public function getFormId()
  {
    return "cnpcaccount_pledgetv_channels";
  }
  
  /**
    * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state)
  {
    $form = $this->displaypledgeTVChannelsForm($form, $form_state);
    return $form;
  }
  
  /**
   * displaypledgeTVChannelsForm
   * Displays pledgeTV channels into a table
   * @param type $form
   * @param type $form_state
   * @return string
   */
  public function displaypledgeTVChannelsForm($form, $form_state)
  {
    $form['base_url_cnpc'] = [
      '#type' => 'hidden',
      '#default_value' => base_path(),
      '#attributes' => ["id" => "base_url_cnpc"],
    ];
    $form['cnpc_menu'] = [
      '#prefix' => '<div class="cnp_heading"><ul>'
        . '<li><a href="cnp_form_help">'.$this->t("Click & Pledge").'</a></li>'
        . '<li><a href="cnp_form">'.$this->t("Form Groups").'</a></li>'
        . '<li><a class="cnpccurrent" href="CnPpledgeTVChannels">'.$this->t('pledgeTV').'<sup class="cnpc-regsymbol">&reg;</sup></a></li>'
        . '<li><a href="cnp_formssettings">'.$this->t("Settings").'</a></li>'
        . '</ul>',
      '#suffix' => '</div>',
    ];
    $form['cnpc_heading'] = [
      '#prefix' => '<div class="cnp_heading1">',
      '#suffix' => '</div>',
    ];
    $html = '<div class="cnpc-btn-center"><a href="add_channel_group" class="cnpc_button_link_add">'.$this->t("Add New Channel Group").'</a></div>';

    $form['button_link_html'] = [
      '#type' => 'markup',
      '#markup' => $html,
    ];
    $form['table_group_start'] = [
      "#prefix" => "<div class='tablelist_group'>",
    ];
    if (count($this->getRecords()) > 0) {
      $form['table_tag_start'] = [
        "#prefix" => "<div><table id='table_form_group' class='table_form_group'>
                            <thead>
                                <tr>
                                    <th>".$this->t("Group Name")."</th>
                                    <th>".$this->t("Account#")."</th>
                                     <th>".$this->t("Short Code")." <span class='cnpc_question'>&#63;</span><div class='cnpc_shortcode_tooltip'>".$this->t("Please copy this code and place it in your required content pages, posts or any custom content types. This code will run the series of the channels which has been added to this particular channel Group inside your content page.")."</div></th>
                                    <th>".$this->t("Start Date/Time")."</th>
                                    <th>".$this->t("End Date/Time")."</th>
                                    <th>".$this->t("Active Channel(s)")."</th>
                                    <th>".$this->t("Last Modified")."</th>
                                    <th>".$this->t("Status")."</th>
                                    <th>".$this->t("Actions")."</th>
                                </tr>
                            </thead>
                            <tbody>"
      ];
      $channelGroups = $this->getRecords();
      $rg = 1;
      foreach ($channelGroups as $fg) {
        if ($fg->cnpchannelgrp_channel_EndDate == "0000-00-00 00:00:00") {
          $enddate = "";
        } else {
          $enddate = date("F d, Y h:i:s a", strtotime($fg->cnpchannelgrp_channel_EndDate));
        }
        if ($this->checkFormsExpiry($fg->cnpchannelgrp_channel_StartDate, $enddate) == "no") {
          $flink = "<a id='formstatus_" . $fg->cnpchannelgrp_ID . "' class='ptvformstatus' href='' data-fgid='" . $fg->cnpchannelgrp_ID . "' data-fstatus='" . $fg->cnpchannelgrp_status . "'>" . $fg->cnpchannelgrp_status . "</a>";
        } else {
          $flink = "<a class='ptvformstatus' href=''>".$this->t("Expired")."</a>";
        }
        $form['table_row_form_groups_' . $rg] = [
          "#prefix" => "<tr>
                                   <td>" . $fg->cnpchannelgrp_groupname . "</td>
                                   <td>" . $fg->cnpstngs_AccountNumber . "</td>
                                   <td>" . $fg->cnpchannelgrp_shortcode . "</td>
                                   <td>" . date("F d, Y h:i:s a", strtotime($fg->cnpchannelgrp_channel_StartDate)) . "</td>
                                   <td>" . $enddate . "</td>
                                   <td>" . count($this->getNoofChannels($fg->cnpchannelgrp_ID)) . "</td>
                                   <td>" . date("F d, Y h:i:s a", strtotime($fg->cnpchannelgrp_Date_Modified)) . "</td>
                                   <td>".$flink."</td>
                                   <td><a href='viewchannels/" . $fg->cnpchannelgrp_ID . "'><span class='view_icon'></span></a> | <a href='editchannels/" . $fg->cnpchannelgrp_ID . "'><span class='edit_icon'></span></a> | <a id='deletechannelInfo' class='deletechannelInfo' data-recid='" . $fg->cnpchannelgrp_ID . "' href='#'><span class='bin_icon'></span></a> </td>",
          "#suffix" => "</tr>",
        ];
        $rg++;
      }
      $form['table_tag_end'] = [
        "#suffix" => "</tbody>
                       </table></div>",
      ];
    } else {
      $form['no_records'] = [
        "#prefix" => "<div><h3>".$this->t("No Records Found.")."</h3>",
        "#suffix" => "</div>",
      ];
    }
    $form['table_group_end'] = [
      "#suffix" => "</div>",
    ];
    return $form;
  }
  
  /** 
   * @param array $form
   * @param FormStateInterface $form_state
   */
  public function validateForm(array &$form, FormStateInterface $form_state)
  {
    //form validations are hasling with javascript
  }
  
  /**
   * @param array $form
   * @param FormStateInterface $form_state
   */
  public function submitForm(array &$form, FormStateInterface $form_state)
  {
    //saving form data handling with ajax call
  }
  
  /**
   * get pledgeTV channels from db to display into a table
   * @return type
   */
  public function getRecords()
  {
    $prefix = $this->connection->tablePrefix();
    $table_name = $prefix . 'dp_cnpc_channelgrp';
    $settingstable_name = $prefix . 'dp_cnpcsettingsdtl';
    $sql = "SELECT * FROM " . $table_name . " INNER JOIN " . $settingstable_name . " ON cnpchannelgrp_cnpstngs_ID=cnpstngs_ID";
    $query = $this->connection->query($sql);
    return $query->fetchAll();
  }
  
  /**
   * getNoofChannels
   * to get the total no of channels under a form group
   * @param type $id
   * @return type
   */
  public function getNoofChannels($id)
  {
    $prefix = $this->connection->tablePrefix();
    $table_name = $prefix . 'dp_cnpc_channeldtl';
    $sql = "SELECT cnpchannel_id,cnpchannel_cnpchannelgrp_ID,cnpchannel_channelName,cnpchannel_channelStartDate,"
            . "cnpchannel_channelEndDate,cnpchannel_channelStatus,cnpchannel_DateCreated,"
            . "cnpchannel_DateModified FROM " . $table_name . " where cnpchannel_cnpchannelgrp_ID=" . $id;
    $query = $this->connection->query($sql);
    return $query->fetchAll();
  }
  
/**
 * checkFormsExpiry
 * Calculates expiry date of a form
 * @param type $startDT
 * @param type $endDT
 * @return string
 */
  public function checkFormsExpiry($startDT, $endDT)
  {
    date_default_timezone_set(drupal_get_user_timezone());
    $currDT = date('Y-m-d h:i:s a');
    $currDT = strtotime($currDT);
    $startDT = strtotime($startDT);
    $endDT = strtotime($endDT);
    if($startDT > $currDT)
    {
        return "no";
    }
    if ($endDT) {
      if (($currDT >= $startDT) && ($currDT <= $endDT)) {
        return "no";
      } else {
        return "yes";
      }
    } else {
      return "no";
    }
  }
  
}
