<?php

namespace Drupal\clickandpledge_connect\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use \SoapClient;
use SimpleXMLElement;

/**
 * uses to edit the pledgeTV channels
 */
class EditChannels extends FormBase
{
  /**
   * 
   */
  const CFCNP_PLUGIN_UID = "14059359-D8E8-41C3-B628-E7E030537905";
  const CFCNP_PLUGIN_SKY = "5DC1B75A-7EFA-4C01-BDCD-E02C536313A3";
  const CFCNP_SOAP_VER = "SOAP_1_1";
  
  /**
   * Database connection
   * @var type 
   */
  private $connection=null;
  
  /**
   * loads database connection into class
   */
  public function __construct() {
    $this->connection = \Drupal::service('database');
  }
  
  /**
    * {@inheritdoc}
   */
  public function getFormId()
  {
    return "cnpc_edit_channel_group";
  }
  
  /**
    * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state)
  {
    $form = $this->displayEditCnpcForm($form, $form_state);
    return $form;
  }
  
  /**
   * displayEditCnpcForm
   * create a channel edit form for editing
   * @param type $form
   * @param type $form_state
   * @return string
   */
  public function displayEditCnpcForm($form, $form_state)
  {
    date_default_timezone_set(drupal_get_user_timezone());
    $path = \Drupal::request()->getpathInfo();
    $arg  = explode('/', $path);
    $reqID = end($arg);
    $formInfo = $this->getChannelInfo($reqID);
    $formDetails = $this->getChannelDetails($reqID);
    $form['cnpc_menu'] = [
      '#prefix' => '<div class="cnp_heading"><ul>'
        . '<li><a href="../cnp_form_help">'.$this->t("Click & Pledge").'</a></li>'
        . '<li><a href="../cnp_form">'.$this->t("Form Groups").'</a></li>'
        . '<li><a class="cnpccurrent" href="../cnppledgetvchannels">'.$this->t("pledgeTV").'<sup class="cnpc-regsymbol">&reg;</sup></a></li>'
        . '<li><a href="../cnp_formssettings">'.$this->t("Settings").'</a></li>'
        . '</ul>',
      '#suffix' => '</div>',
    ];

    $html = '<a href="../cnppledgetvchannels" class="cnpc_button_link_edit">'.$this->t("Go back to Channel Groups").'</a>';
    $form['gobackbtn_link_html'] = [
      '#type' => 'markup',
      '#markup' => $html,
    ];
    $form['cnpc_heading'] = [
      '#prefix' => '<div class="cnp_heading1">',
      '#suffix' => '</div>',
    ];
    $form['cnpc_channel_group_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Channel Group Name*'),
      '#description' => $this->t('Please enter the channel name<br><span class="cnpc_channelexists_error"></span>'),
      '#default_value' => $formInfo->cnpchannelgrp_groupname,
      '#attributes' => ["id" => "cnpc_channel_group_name"],
      '#disabled' => true,
    ];
    $form['hidden_fg_name'] = [
      '#type' => 'hidden',
      '#default_value' => $formInfo->cnpchannelgrp_groupname,
      '#attributes' => ["id" => "hidden_fg_name"],
    ];
    $data = $this->getRecords();
    if (count($data) > 0) {
      if (count($data) == 1) {
        $disabled = TRUE;
      } else {
        $disabled = FALSE;
      }
    } else {
      $disabled = false;
    }
    $options = [];
    foreach ($data as $rec) {
      $options[$rec->cnpstngs_AccountNumber . "||" . $rec->cnpstngs_guid . "||" . $rec->cnpstngs_ID] = $rec->cnpstngs_frndlyname . ' ( ' . $rec->cnpstngs_AccountNumber . ' )';
    }
    $form['base_url_cnpc'] = [
      '#type' => 'hidden',
      '#default_value' => base_path(),
      '#attributes' => ["id" => "base_url_cnpc"],
    ];
    $form['cnpc_edit_id'] = [
      '#type' => 'hidden',
      '#default_value' => $reqID,
      '#attributes' => ["id" => "cnpc_edit_id"],
    ];
    $form['cnpc_action'] = [
      '#type' => 'hidden',
      '#default_value' => 'edit',
      '#attributes' => ["id" => "cnpc_action"],
    ];
    $form['cnpc_accounts_hidden'] = [
      '#type' => 'hidden',
      '#default_value' => $formInfo->cnpstngs_AccountNumber,
      '#attributes' => ["id" => "cnpc_accounts_hidden"],
    ];
    $form['cnpc_accounts'] = [
      '#type' => 'select',
      '#title' => $this->t('Account(s)*'),
      '#options' => $options,
      '#default_value' => "",
      '#attributes' => ["id" => "cnpc_accounts"],
      '#disabled' => TRUE,
    ];
    $form['cnpc_start_date_time'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Start Date/Time* [TimeZone: ' . drupal_get_user_timezone() . ']'),
      '#attributes' => ["id" => "start_date_time"],
      '#default_value' => date("F d, Y h:i:s a", strtotime($formInfo->cnpchannelgrp_channel_StartDate)),
    ];
    if ($formInfo->cnpchannelgrp_channel_EndDate == "0000-00-00 00:00:00") {
      $ed = "";
    } else {
      $ed = date("F d, Y h:i:s a", strtotime($formInfo->cnpchannelgrp_channel_EndDate));
    }
    $form['cnpc_end_date_time'] = [
      '#type' => 'textfield',
      '#title' => $this->t('End Date/Time'),
      '#attributes' => ["id" => "end_date_time"],
      '#default_value' => $ed,
    ];
    $form['cnpc_message'] = [
      '#type' => 'textarea',
      '#title' => $this->t('No Valid Channel Message'),
      '#attributes' => ["id" => "cnpc_message"],
      '#default_value' => $formInfo->cnpchannelgrp_custommsg,
    ];
    $form['cnpc_status'] = [
      '#type' => 'select',
      '#title' => $this->t('Status'),
      '#options' => ["active" => $this->t("Active"), "inactive" => $this->t("Inactive")],
      '#attributes' => ["id" => "cnpc_status"],
      '#default_value' => $formInfo->cnpchannelgrp_status,
    ];
    //hidden form Starts here
    $noofFoms = count($formDetails);
    $form['cnpcchnl_counter'] = [
      '#type' => 'hidden',
      '#attributes' => ["id" => "cnpcchnl_counter"],
      '#default_value' => $noofFoms,
    ];
    if ($noofFoms == 1) {
      $showBlock = "block";
    } else {
      $showBlock = "none";
    }
    $form['cnpc_settings_form_start'] = [
      '#prefix' => '<div class="cnpc_settings_form" id="cnpc_settings_form"><ol><li>'.$this->t("Select your Channel, enter a start date and click SAVE.").'</li><li>'.$this->t("Copy the 'shortcode' from pledgeTV<sup class='cnpc-regsymbol'>&reg;</sup> Channels page, to your Drupal page. Multiple Channels may be added. Channels will display in order of start date. If start dates overlap, the first Channel in the list will show first.").'</li></ol>'
        . '<table id="custchnlrows"><tr>
        <th>'.$this->t("Channel*").'</th>
        <th>'.$this->t("Start Date/Time*").'</th>
        <th>'.$this->t("End Date/Time").'</th>
        <th>&nbsp;</th>
        </tr><tbody id="dynachnlrows">',
    ];
    $getInfo = $this->getChannelInfo($reqID);
    $campId = $getInfo->cnpstngs_AccountNumber . "@" . $getInfo->cnpstngs_guid . "@" . $getInfo->cnpstngs_ID;
    $campOpt = $this->getAllChannelsList($campId);
    for ($f = 0; $f < count($formDetails); $f++) {
      $fl = $getInfo->cnpstngs_AccountNumber . "@" . $getInfo->cnpstngs_guid . "@" . $formDetails[$f]->cnpstngs_ID;
      if ($formDetails[$f]->cnpchannel_channelEndDate == "0000-00-00 00:00:00") {
        $formenddate = "";
      } else {
        $formenddate = date("F d, Y h:i:s a", strtotime($formDetails[$f]->cnpchannel_channelEndDate));
      }

      $form['tr_start_' . $f] = [
        "#prefix" => "<tr id='row_$f'>",
      ];
      $form['cnpc_chnl_list_' . $f] = [
        "#prefix" => "<td>",
        '#type' => 'select',
        "#options" => $campOpt,
        "#default_value" => $formDetails[$f]->cnpchannel_channelName,
        '#attributes' => ['class' => ['cnpc_chnl_list'], 'id' => 'cnpc_chnl_list_' . $f, "data-rowindex" => $f, "data-opttext" => $formDetails[$f]->cnpchannel_channelName],
        "#suffix" => "</td>"
      ];
      $form['formguid_' . $f]['#theme_wrappers'] = [];
      $form['chnlstartdate_' . $f] =[
        "#prefix" => "<td>",
        '#type' => 'textfield',
        "#default_value" => date("F d, Y h:i:s a", strtotime($formDetails[$f]->cnpchannel_channelStartDate)),
        '#attributes' => ['class' => ['chnlstartdate'], 'id' => 'chnlstartdate_' . $f, "size" => 25],
        "#suffix" => "</td>"
      ];
      $form['startdate_' . $f]['#theme_wrappers'] = [];
      $form['chnlenddate_' . $f] = [
        "#prefix" => "<td>",
        '#type' => 'textfield',
        "#default_value" => $formenddate,
        '#attributes' => ['class' => ['chnlenddate'], 'id' => 'chnlenddate_' . $f, "size" => 25],
        "#suffix" => "</td>",
      ];
      $form['enddate_' . $f]['#theme_wrappers'] = [];
      $form['deletebtn_' . $f] = [
        "#prefix" => "<td><a href='#' id='deleteRec_'.$f class='deleteRec' data-target='edit' data-caction='edittv' data-recid='" . $formDetails[$f]->cnpchannel_id . "' data-index='" . $f . "'><span class='bin_icon'></span></a>",
        "#suffix" => "</td>"
      ];
      $form['edn'] =["#suffix" => "</td>"];
      $form['tr_end_' . $f] = [
        "#suffix" => "</tr>",
      ];
    }
    $form['table_tag_end'] = [
      "#suffix" => "</tbody>
                       </table><a href='#' id='addchannelrows'>Add Channel</a>",
    ];
    $form['cnpc_settings_form_end'] = [
      '#suffix' => '</div>'
    ];
    $html1 = '<div><a href="../cnppledgetvchannels" class="cnpc_button_link_bottom">Go back to Channel Groups</a></div>';
    $form['gobackbtn_link_html1'] = [
      '#type' => 'markup',
      '#markup' => $html1,
    ];
    $form['cnpc_inital_buttons_start'] = [
      '#prefix' => '<div class="cnpc_inital_buttons">',
    ];
    $form['save'] = [
      '#type' => 'button',
      '#value' => $this->t('Save'),
      '#attributes' => ["id" => "finalchnlsave"],
    ];
    $html2 = '<a href="../cnppledgetvchannels" class="button button--reset js-form-submit form-submit">'.$this->t("Close").'</a>';
    $form['gobackbtn_link_html2'] = [
      '#type' => 'markup',
      '#markup' => $html2,
    ];
    $form['cnpc_inital_buttons_end'] = [
      '#suffix' => '</div>',
    ];
    $form['cnpc_hide_buttons_start'] = [
      '#prefix' => '<div class="cnpc_hide_show_buttons">',
    ];
    $form['final_save'] = [
      '#type' => 'button',
      '#value' => $this->t('Save'),
      '#attributes' => ["id" => "updateforms"],
    ];
    $form['cnpc_hide_buttons_end'] = [
      '#suffix' => '</div>'
    ];
    return $form;
  }
  
  /**
    * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state)
  {
    //form validations are hasling with javascript
  }
  
  /**
    * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state)
  {
    //saving form data handling with ajax call
  }
  
  /**
   * getRecords
   * get all channels data
   * @return type
   */
  public function getRecords()
  {
    $connection = \Drupal::database();
    $prefix = $this->connection->tablePrefix();
    $table_name = $prefix . 'dp_cnpcsettingsdtl';
    $sql = "SELECT cnpstngs_ID,cnpstngs_frndlyname,cnpstngs_AccountNumber,cnpstngs_guid,cnpstngs_status,cnpstngs_Date_Created,"
            . "cnpstngs_Date_Modified FROM " . $table_name;
    $query = $this->connection->query($sql);
    return $query->fetchAll();
  }
  
  /**
   * getChannelInfo
   * get the channel information
   * @param type $id
   * @return type
   */
  public function getChannelInfo($id)
  {
    $prefix = $this->connection->tablePrefix();
    $table_name = $prefix . 'dp_cnpc_channelgrp';
    $sttable_name = $prefix . 'dp_cnpcsettingsdtl';
    $sql = "SELECT * FROM " . $table_name . " inner join " . $sttable_name . " on cnpchannelgrp_cnpstngs_ID = cnpstngs_ID where cnpchannelgrp_ID=" . $id;
    $query = $this->connection->query($sql);
    return $query->fetch();
  }
  
  /**
   * getChannelDetails
   * get the channel details
   * @param type $id
   * @return type
   */
  public function getChannelDetails($id)
  {
    $prefix = $this->connection->tablePrefix();
    $table_name = $prefix . 'dp_cnpc_channeldtl';
    $sql = "SELECT cnpchannel_id,cnpchannel_cnpchannelgrp_ID,cnpchannel_channelName,cnpchannel_channelStartDate,"
            . "cnpchannel_channelEndDate,cnpchannel_channelStatus,cnpchannel_DateCreated,"
            . "cnpchannel_DateModified FROM " . $table_name . " where cnpchannel_cnpchannelgrp_ID=" . $id;
    $query = $this->connection->query($sql);
    return $query->fetchAll();
  }
  
  /**
   * get all the channels list from SOAP service
   * @param type $variable
   * @return type
   */
  public function getAllChannelsList($variable)
  {
    $str = explode("@", $variable);
    $connect  = ['soap_version' => self::CFCNP_SOAP_VER, 'trace' => 1, 'exceptions' => 0];
    $module_handler = \Drupal::service('module_handler');
    $host = \Drupal::request()->getSchemeAndHttpHost();
    $module_path = $module_handler->getModule('clickandpledge_connect')->getPath() . "/Auth2.wsdl";
    $client   = new SoapClient($module_path, $connect);
    $accountguid = $str[1];
    $accountid = $str[0];
    $xmlr  = new SimpleXMLElement("<GetPledgeTVChannelList></GetPledgeTVChannelList>");
    $xmlr->addChild('accountId', $accountid);
    $xmlr->addChild('AccountGUID', $accountguid);
    $xmlr->addChild('username', self::CFCNP_PLUGIN_UID);
    $xmlr->addChild('password', self::CFCNP_PLUGIN_SKY);
    $response = $client->GetPledgeTVChannelList($xmlr);
    $responsearr =  $response->GetPledgeTVChannelListResult->PledgeTVChannel;
    if (count($responsearr) == 1) {
      $camrtrnval[$responsearr->ChannelURLID] = $responsearr->ChannelName;
    } else {
      for ($inc = 0; $inc < count($responsearr); $inc++) {
        $camrtrnval[$responsearr[$inc]->ChannelURLID] = $responsearr[$inc]->ChannelName;
      }
    }
    natcasesort($camrtrnval);
    array_unshift($camrtrnval, "Select Channel Name");
    return  $camrtrnval;
  }
  
}
