<?php

namespace Drupal\clickandpledge_connect\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use \SoapClient;
use SimpleXMLElement;

/**
 * uses to edit CONNECT forms
 */
class EditForms extends FormBase
{
  const CFCNP_PLUGIN_UID = "14059359-D8E8-41C3-B628-E7E030537905";
  const CFCNP_PLUGIN_SKY = "5DC1B75A-7EFA-4C01-BDCD-E02C536313A3";
  
  /**
   * declaare SOAP version
   */
  const CFCNP_SOAP_VER = "SOAP_1_1";
  
  /**
   * CFCNP_SERVICE_URL
   * service URL to authenticate and to get forms and campaigns from click and pledge CONNECT platform
   */
  const CFCNP_SERVICE_URL = "https://resources.connect.clickandpledge.com/wordpress/Auth2.wsdl";
  
  /**
   * Database connection
   * @var type 
   */
  private $connection=null;
  
  /**
   * loads database connection into class
   */
  public function __construct() {
    $this->connection = \Drupal::service('database');
  }
  
  /**
    * {@inheritdoc}
   **/
  public function getFormId()
  {
    return "cnpc_edit_form_group";
  }
  
  /**
    * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state)
  {
    $form = $this->displayEditCnpcForm($form, $form_state);
    return $form;
  }
  
  /**
   * displayEditCnpcForm
   * creates a form to edit the CONNECT forms
   * @param type $form
   * @param type $form_state
   * @return string
   */
  public function displayEditCnpcForm($form, $form_state)
  {
    date_default_timezone_set(drupal_get_user_timezone());
    $path = \Drupal::request()->getpathInfo();
    $arg  = explode('/', $path);
    $reqID = end($arg);
    $formInfo = $this->getFormInfo($reqID);
    $formDetails = $this->getFormDetails($reqID);
    $form['cnpc_menu'] = [
      '#prefix' => '<div class="cnp_heading"><ul>'
        . '<li><a href="../cnp_form_help">'.$this->t("Click & Pledge").'</a></li>'
        . '<li><a class="cnpccurrent" href="../cnp_form">'.$this->t("Form Groups").'</a></li>'
        . '<li><a href="../cnppledgetvchannels">'.$this->t("pledgeTV").'<sup class="cnpc-regsymbol">&reg;</sup></a></li>'
        . '<li><a href="../cnp_formssettings">'.$this->t("Settings").'</a></li>'
        . '</ul>',
      '#suffix' => '</div>',
    ];
    $html = '<a href="../cnp_form" class="cnpc_button_link_edit">'.$this->t("Go back to Form Groups").'</a>';
    $form['gobackbtn_link_html'] = [
      '#type' => 'markup',
      '#markup' => $html,
    ];
    $form['cnpc_heading'] = [
      '#prefix' => '<div class="cnp_heading1">',
      '#suffix' => '</div>',
    ];
    $form['cnpc_form_group_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Form Group Name*'),
      '#description' => $this->t('Please enter the form group name<br><span class="cnpc_formexists_error"></span>'),
      '#default_value' => $formInfo->cnpform_groupname,
      '#attributes' => ["id" => "cnpc_form_group_name"],
      '#disabled' => true,
    ];
    $form['hidden_fg_name'] = [
      '#type' => 'hidden',
      '#default_value' => $formInfo->cnpform_groupname,
      '#attributes' => ["id" => "hidden_fg_name"],
    ];
    $data = $this->getRecords();
    if (count($data) > 0) {
      if (count($data) == 1) {
        $disabled = TRUE;
      } else {
        $disabled = FALSE;
      }
    } else {
      $disabled = false;
    }
    $options = [];
    foreach ($data as $rec) {
      $options[$rec->cnpstngs_AccountNumber . "||" . $rec->cnpstngs_guid . "||" . $rec->cnpstngs_ID] = $rec->cnpstngs_frndlyname . ' ( ' . trim($rec->cnpstngs_AccountNumber) . ' )';
    }
    $form['base_url_cnpc'] = [
      '#type' => 'hidden',
      '#default_value' => base_path(),
      '#attributes' => ["id" => "base_url_cnpc"],
    ];
    $form['cnpc_edit_id'] = [
      '#type' => 'hidden',
      '#default_value' => $reqID,
      '#attributes' => ["id" => "cnpc_edit_id"],
    ];
    //popup textarea for url params
    $form['cnpc_params_popup'] = [
      "#prefix" => '<div id="cnpc_myModal" class="cnpc-modal">
              <div class="cnpc-modal-content">
                <div class="cnpc-modal-header">
                  <span class="cnpc-close">&times;</span>
                  <h2>'.$this->t("URL Parameter(s)").'</h2>
                </div>
                <div class="cnpc-modal-body">'
    ];
    $form['cnpc_params_textarea'] = [
      "#prefix" => '<div class="cnpc-form-group-params">',
      "#type" => "textarea",
      "#atrributes" => ['class' => ['paramsfeild']],
      "#suffix" => "</div>",
    ];
    $form['cnpc_params_textarea']['#theme_wrappers'] = [];
    $form["cnpc_params_buttons_start"] = [
      "#prefix" => "</div><div class='cnpc-modal-footer'>",
    ];
    $form['cnpc_params_button_add'] = [
      "#prefix" => '<div>',
      '#type' => 'button',
      '#value' => $this->t('Add'),
      '#attributes' => ['class' => ['popupsavebtn'], "id" => "addparams"],
      "#suffix" => '</div>',
    ];
    $form['cnpc_params_button_close'] = [
      "#prefix" => '<div>',
      '#type' => 'button',
      '#value' => $this->t('Close'),
      '#attributes' => ['class' => ['popupclosebtn'], "id" => "closeparams"],
      "#suffix" => '</div>',
    ];
    $form['cnpc_params_button_saveclose'] = [
      "#prefix" => '<div>',
      '#type' => 'button',
      '#value' => $this->t('Add & Close'),
      '#attributes' => ['class' => ['popupsaveclosebtn'], "id" => "savecloseparams"],
      "#suffix" => '</div>',
    ];
    $html22 = '</div><p class="cnpc_note_text"><b>Note:</b> '.$this->t("Separate with ampersand").' (&) <a target="_blank" href="https://support.clickandpledge.com/s/article/connect-url-parameters1"><b>'.$this->t("Read More...").'</b></a></p>';
    $form['readmore_link_html22'] = [
      '#type' => 'markup',
      '#markup' => $html22,
    ];
    $form["cnpc_params_buttons_end"] = [
      "#suffix" => "</div></div>",
    ];
    $form['cnpc_action'] = [
      '#type' => 'hidden',
      '#default_value' => 'edit',
      '#attributes' => ["id" => "cnpc_action"],
    ];
    $form['cnpc_accounts_hidden'] = [
      '#type' => 'hidden',
      '#default_value' => $formInfo->cnpform_AccountNumber,
      '#attributes' => ["id" => "cnpc_accounts_hidden"],
    ];
    $form['cnpc_accounts'] = [
      '#type' => 'select',
      '#title' => $this->t('Account(s)*'),
      '#options' => $options,
      '#default_value' => "",
      '#attributes' => ["id" => "cnpc_accounts"],
      '#disabled' => TRUE,
    ];
    $form['cnpc_start_date_time'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Start Date/Time* [TimeZone: ' . drupal_get_user_timezone() . ']'),
      '#attributes' => ["id" => "start_date_time"],
      '#default_value' => date("F d, Y h:i:s a", strtotime($formInfo->cnpform_Form_StartDate)),
    ];
    if ($formInfo->cnpform_Form_EndDate == "0000-00-00 00:00:00") {
      $ed = "";
    } else {
      $ed = date("F d, Y h:i:s a", strtotime($formInfo->cnpform_Form_EndDate));
    }
    $form['cnpc_end_date_time'] = [
      '#type' => 'textfield',
      '#title' => $this->t('End Date/Time'),
      '#attributes' => ["id" => "end_date_time"],
      '#default_value' => $ed,
    ];
    $form['cnpc_display_type'] = [
      '#type' => 'select',
      '#title' => $this->t('Display Type'),
      '#options' => ["inline" => $this->t("Inline"), "popup" => $this->t("Overlay")],
      '#attributes' => ["id" => "cnpc_display_type"],
      '#default_value' => $formInfo->cnpform_type,
    ];
    //hidden form overlay
    $form['overlay_wrapper_start'] = [
      '#prefix' => '<div class="overlay_wrapper">',
    ];
    $form['cnpc_link_type'] = [
      '#type' => 'select',
      '#title' => $this->t('Link Type*'),
      '#options' => ["button" => $this->t("Button"), "image" => $this->t("Image"), "text" => $this->t("Text")],
      '#attributes' => ["id" => "cnpc_link_type"],
      '#default_value' => $formInfo->cnpform_ptype,
    ];
    $form['cnpc_buton_label'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Button Label*'),
      '#attributes' => ["id" => "cnpc_btn_lbl"],
      '#default_value' => $formInfo->cnpform_text,
    ];
    $form['cnpc_upload_image'] = [
      '#type' => 'file',
      '#title' => $this->t('Upload Image*'),
      '#attributes' => ["id" => "cnpc_upload_image"],
      '#default_value' => "",
    ];
    $form['cnpc_upload_image_hidden'] = [
      '#type' => 'hidden',
      '#attributes' => ["id" => "cnpc_upload_image_hidden"],
      '#default_value' => $formInfo->cnpform_img,
    ];
    $form['overlay_wrapper_end'] = [
      '#suffix' => '</div>',
    ];
    $form['cnpc_message'] = [
      '#type' => 'textarea',
      '#title' => $this->t('No Valid Form Message'),
      '#attributes' => ["id" => "cnpc_message"],
      '#default_value' => $formInfo->cnpform_custommsg,
    ];
    $form['cnpc_status'] = [
      '#type' => 'select',
      '#title' => $this->t('Status'),
      '#options' => ["active" => $this->t("Active"), "inactive" => $this->t("Inactive")],
      '#attributes' => ["id" => "cnpc_status"],
      '#default_value' => $formInfo->cnpform_status,
    ];
    //hidden form Starts here
    $noofFoms = count($formDetails);
    $form['cnpc_counter'] = [
      '#type' => 'hidden',
      '#attributes' => ["id" => "cnpc_counter"],
      '#default_value' => $noofFoms,
    ];
    if ($noofFoms == 1) {
      $showBlock = "block";
    } else {
      $showBlock = "none";
    }
    $form['cnpc_settings_form_start'] = [
      '#prefix' => '<div class="cnpc_settings_form" id="cnpc_settings_form">'.$this->t("Select your CONNECT campaign, choose a payment form, enter a start date and click SAVE. Copy the shortcode from Click & Pledge Form Groups page to enter on your WordPress page. Multiple forms may be added to display in order by start date. If dates overlap, the first form in the list will show.").''
        . '<table id="custrows"><tr>
        <th>'.$this->t("Campaign*").'</th>
        <th>'.$this->t("Form*").'</th>
        <th>'.$this->t("Form GUID*").'</th>
        <th>'.$this->t("Start Date/Time").'</th>
        <th>'.$this->t("End Date/Time").'</th>
        <th>&nbsp;</th>
        </tr><tbody id="dynarows">',
    ];
    $getInfo = $this->getFormInfo($reqID);
    $campId = $getInfo->cnpform_AccountNumber . "@" . $getInfo->cnpform_guid . "@" . $getInfo->cnpform_cnpstngs_ID;
    $campOpt = $this->getAllCampaignsList($campId);
    for ($f = 0; $f < count($formDetails); $f++) {
      $fl = $getInfo->cnpform_AccountNumber . "@" . $getInfo->cnpform_guid . "@" . $formDetails[$f]->cnpform_CampaignName;
      $formList = $this->getActivityFormsList($fl);
      if ($formDetails[$f]->cnpform_FormEndDate == "0000-00-00 00:00:00") {
        $formenddate = "";
      } else {
        $formenddate = date("F d, Y h:i:s a", strtotime($formDetails[$f]->cnpform_FormEndDate));
      }

      $form['tr_start_' . $f] = [
        "#prefix" => "<tr id='row_$f'>",
      ];
      $form['cnpc_camp_list_' . $f] = [
        "#prefix" => "<td>",
        '#type' => 'select',
        "#options" => $campOpt,
        "#default_value" => $formDetails[$f]->cnpform_CampaignName,
        '#attributes' => ['class' => ['cnpc_camp_list'], 'id' => 'cnpc_camp_list_' . $f, "data-rowindex" => $f, "data-opttext" => $formDetails[$f]->cnpform_CampaignName],
        "#suffix" => "</td>"
      ];
      $form['cnpc_camp_list_' . $f]['#theme_wrappers'] = [];
      $form['cnpc_form_list_' . $f] = [
        "#prefix" => "<td>",
        '#type' => 'select',
        "#options" => $formList,
        "#default_value" => $formDetails[$f]->cnpform_FormName,
        '#attributes' => ['class' => ['cnpc_form_list'], 'id' => 'cnpc_form_list_' . $f, "data-formindex" => $f, "data-opttext" => $formDetails[$f]->cnpform_FormName],
        "#suffix" => "</td>"
      ];
      $form['cnpc_form_list_' . $f]['#theme_wrappers'] = [];
      $form['formguid_' . $f] = [
        "#prefix" => "<td>",
        '#type' => 'textfield',
        "#default_value" => $formDetails[$f]->cnpform_GUID,
        '#attributes' => ['id' => 'formguid_' . $f, "disabled" => "disabled", "size" => 25],
        "#suffix" => "</td>"
      ];
      $form['formguid_' . $f]['#theme_wrappers'] = [];
      $form['startdate_' . $f] = [
        "#prefix" => "<td>",
        '#type' => 'textfield',
        "#default_value" => date("F d, Y h:i:s a", strtotime($formDetails[$f]->cnpform_FormStartDate)),
        '#attributes' => ['class' => ['cnpcstartdate'], 'id' => 'startdate_' . $f, "size" => 25],
        "#suffix" => "</td>"
      ];
      $form['startdate_' . $f]['#theme_wrappers'] = [];
      $form['enddate_' . $f] = [
        "#prefix" => "<td>",
        '#type' => 'textfield',
        "#default_value" => $formenddate,
        '#attributes' => ['class' => ['cnpcenddate'], 'id' => 'enddate_' . $f, "size" => 25],
        "#suffix" => "</td>",
      ];
      $form['enddate_' . $f]['#theme_wrappers'] = [];
      $form['hidden_params_' . $f] = [
        '#type' => 'hidden',
        '#default_value' => $formDetails[$f]->cnpform_urlparameters,
        '#attributes' => ["id" => "hidden_params_" . $f],
      ];
      $module_handler = \Drupal::service('module_handler');
      $module_path = $module_handler->getModule('clickandpledge_connect')->getPath();
      $form['deletebtn_' . $f] = [
        "#prefix" => "<td class='cnpc_delurl_btns'><div class='cnpc_url_btn'><a href='#' class='cnpc-myBtn' data-index='" . $f . "'>URL<b>+</b></a></div> &nbsp; <div class='cnpc_delete_btn'><a href='#' id='deleteRec_'.$f class='deleteRec' data-target='edit' data-caction='editform' data-recid='" . $formDetails[$f]->cnpform_id . "' data-index='" . $f . "'><span class='bin_icon'></span></a></div>",
        "#suffix" => "</td>"
      ];
      $form['edn'] = ["#suffix" => "</td>"];
      $form['tr_end_' . $f] = [
        "#suffix" => "</tr>",
      ];
    }
    $form['table_tag_end'] = [
      "#suffix" => "</tbody>
                       </table><a href='#' id='addrows'>Add Form</a>",
    ];
    $html1 = '<a href="../cnp_form" class="cnpc_button_link_bottom">Go back to Form Groups</a>';
    $form['gobackbtn_link_html1'] = [
      '#type' => 'markup',
      '#markup' => $html1,
    ];
    $form['cnpc_settings_form_end'] = [
      '#suffix' => '</div>'
    ];
    $form['cnpc_inital_buttons_start'] = [
      '#prefix' => '<div class="cnpc_inital_buttons">',
    ];
    $form['save'] = [
      '#type' => 'button',
      '#value' => $this->t('Save'),
      '#attributes' => ["id" => "finalsave"],
    ];
    $html2 = '<a id="resetbtn" href="../cnp_form" class="button button--reset js-form-submit form-submit">Close</a>';
    $form['gobackbtn_link_html2'] = [
      '#type' => 'markup',
      '#markup' => $html2,
    ];
    $form['cnpc_inital_buttons_end'] = [
      '#suffix' => '</div>',
    ];
    $form['cnpc_hide_buttons_start'] = [
      '#prefix' => '<div class="cnpc_hide_show_buttons">',
    ];

    $form['final_save'] = [
      '#type' => 'button',
      '#value' => $this->t('Save'),
      '#attributes' => ["id" => "updateforms"],
    ];
    $form['cnpc_hide_buttons_end'] = [
      '#suffix' => '</div>'
    ];
    return $form;
  }
  
  /**
    * {@inheritdoc}
  */
  public function validateForm(array &$form, FormStateInterface $form_state)
  {
    //form validations are hasling with javascript
  }
  
  /**
    * {@inheritdoc}
  */
  public function submitForm(array &$form, FormStateInterface $form_state)
  {
    //saving form data handling with ajax call
  }
  /**
   * getRecords
   * get all the accounts to display into the accounts drop down in the form
   * @return type
   */
  public function getRecords()
  {
    $prefix = $this->connection->tablePrefix();
    $table_name = $prefix . 'dp_cnpcsettingsdtl';
    $sql = "SELECT cnpstngs_ID,cnpstngs_frndlyname,cnpstngs_AccountNumber,cnpstngs_guid,cnpstngs_status,"
            . "cnpstngs_Date_Created,cnpstngs_Date_Modified FROM " . $table_name;
    $query = $this->connection->query($sql);
    return $query->fetchAll();
  }
  
  /**
   * getFormInfo
   * to get the forms information under a form form group
   * @param type $id
   * @return type
   */
  public function getFormInfo($id)
  {
    $prefix = $this->connection->tablePrefix();
    $table_name = $prefix . 'dp_cnpc_forminfo';
    $sql = "SELECT cnpform_GID,cnpform_groupname,cnpform_cnpstngs_ID,cnpform_AccountNumber,cnpform_guid,"
            . "cnpform_type,cnpform_ptype,cnpform_text,cnpform_img,cnpform_shortcode,cnpform_custommsg,"
            . "cnpform_Form_StartDate,cnpform_Form_EndDate,cnpform_status,cnpform_Date_Created,"
            . "cnpform_Date_Modified FROM " . $table_name . " where cnpform_GID=" . $id;
    $query = $this->connection->query($sql);
    return $query->fetch();
  }
  
  /**
   * getFormDetails
   * get form details to display the forms
   * @param type $id
   * @return type
   */
  public function getFormDetails($id)
  {
    $prefix = $this->connection->tablePrefix();
    $table_name = $prefix . 'dp_cnpc_formsdtl';
    $sql = "SELECT cnpform_id,cnpform_cnpform_ID,cnpform_CampaignName,cnpform_FormName,cnpform_GUID,"
            . "cnpform_FormStartDate,cnpform_FormEndDate,cnpform_urlparameters,cnpform_FormStatus,"
            . "cnpform_DateCreated,cnpform_DateModified FROM " . $table_name . " where cnpform_cnpform_ID=" . $id;
    $query = $this->connection->query($sql);
    return $query->fetchAll();
  }
  
  /**
   * to get all the campaigns to display in the forms
   * @param type $variable
   * @return type
   */
  public function getAllCampaignsList($variable)
  {
    $str = explode("@", $variable);
    $connect  = ['soap_version' => self::CFCNP_SOAP_VER, 'trace' => 1, 'exceptions' => 0];
    $client   = new SoapClient(self::CFCNP_SERVICE_URL, $connect);
    $accountguid = $str[1];
    $accountid = $str[0];
    $xmlr  = new SimpleXMLElement("<GetActiveCampaignList2></GetActiveCampaignList2>");
    $xmlr->addChild('accountId', $accountid);
    $xmlr->addChild('AccountGUID', $accountguid);
    $xmlr->addChild('username', self::CFCNP_PLUGIN_UID);
    $xmlr->addChild('password', self::CFCNP_PLUGIN_SKY);
    $response = $client->GetActiveCampaignList2($xmlr);
    $responsearr =  $response->GetActiveCampaignList2Result->connectCampaign;
    if (count($responsearr) == 1) {
      $camrtrnval[$responsearr->alias] = $responsearr->name;
    } else {
      for ($inc = 0; $inc < count($responsearr); $inc++) {
        $camrtrnval[$responsearr[$inc]->alias] = $responsearr[$inc]->name;
      }
    }
    natcasesort($camrtrnval);
    array_unshift($camrtrnval, "Select Campaign Name");
    return  $camrtrnval;
  }
  
  /**
   * getActivityFormsList
   * to get the activity forms list of a campaign 
   * @param type $variable
   * @return type
   */
  public function getActivityFormsList($variable)
  {
    $str = explode("@", $variable);
    $connect  = ['soap_version' => self::CFCNP_SOAP_VER, 'trace' => 1, 'exceptions' => 0];
    $client   = new SoapClient(self::CFCNP_SERVICE_URL, $connect);
    $cnpaccountID      = $str[0];
    $cnpaccountguidID  = $str[1];
    $cnpcampaignId     = $str[2];
    $xmlr  = new SimpleXMLElement("<GetActiveFormList2></GetActiveFormList2>");
    $xmlr->addChild('accountId', $cnpaccountID);
    $xmlr->addChild('AccountGUID', $cnpaccountguidID);
    $xmlr->addChild('username', self::CFCNP_PLUGIN_UID);
    $xmlr->addChild('password', self::CFCNP_PLUGIN_SKY);
    $xmlr->addChild('campaignAlias', $cnpcampaignId);
    $frmresponse    =  $client->GetActiveFormList2($xmlr);
    $frmresponsearr =  $frmresponse->GetActiveFormList2Result->form;
    if (count($frmresponsearr) == 1) {
      $rtrnval1[$frmresponsearr->formGUID] = $frmresponsearr->formName;
      $rtrnval[$frmresponsearr->formGUID] = $frmresponsearr->formName;
    } else {
      for ($finc = 0; $finc < count($frmresponsearr); $finc++) {
        $rtrnval1[$frmresponsearr[$finc]->formGUID] = $frmresponsearr[$finc]->formName;
        $rtrnval[$frmresponsearr[$finc]->formGUID] = $frmresponsearr[$finc]->formName;
      }
    }
    natcasesort($rtrnval);
    array_unshift($rtrnval, "Select Form Name");
    return $rtrnval;
  }
  
}
